Module internal

Module internal 

Internal functions for the shader module. User applications most likely should not use these functions directly nor should they need to.

Functions

module_for
Retrieve the underlying gfx-hal shader module given the lambda-platform implemented shader module. Useful for creating gfx-hal entry points and attaching the shader to rendering pipelines.