Module lambda_platform::winit::winit_exports
source · Expand description
Embedded module for exporting data/types from winit as minimally/controlled as possible. The exports from this module are not guaranteed to be stable.
Structs
Provides a way to retrieve events from the system and from the windows that were registered to
the events loop.
Used to send custom events to
EventLoop.Target that associates windows with an
EventLoop.Enums
Set by the user callback given to the
EventLoop::run method.Describes the input state of a key.
Describes a generic event.
Describes a button of a mouse controller.
Symbolic name for a keyboard key.
Describes an event from a [
Window].